@@ -1,5 +1,5 @@
 package Selenium::Firefox;
-$Selenium::Firefox::VERSION = '0.27';
+$Selenium::Firefox::VERSION = '0.2701';
 # ABSTRACT: Use FirefoxDriver without a Selenium server
 use Moo;
 use Selenium::CanStartBinary::FindBinary qw/coerce_firefox_binary/;
@@ -34,6 +34,11 @@ has '_binary_args' => (
     }
 );
 
+has '+wd_context_prefix' => (
+    is => 'ro',
+    default => sub { '/hub' }
+);
+
 with 'Selenium::CanStartBinary';
 
 
@@ -51,7 +56,7 @@ Selenium::Firefox - Use FirefoxDriver without a Selenium server
 
 =head1 VERSION
 
-version 0.27
+version 0.2701
 
 =head1 SYNOPSIS
 
